@@ -1,6 +1,9 @@
 from django.db import models
+from django.db.models import Model
+from django.db.models.fields.related import ForeignKey
 from django.db.models.query import QuerySet
 from django.db import connections, router
+from django.utils.encoding import smart_str, smart_text
 
 
 def clone_instance(instance, fieldnames=None):
@@ -91,6 +94,13 @@ def get_field_value(obj, field, usedisplay=True, raw_callable=False):
     if not raw_callable and callable(value):
         return value()
 
+    if isinstance(value, models.Model):
+        return smart_text(value)
+    # if isinstance(obj, Model):
+    #     field = get_field_by_path(obj, fieldname)
+    #     if isinstance(field, ForeignKey):
+    #         return unicode(value)
+
     return value
 
 
